---
title: <span class="badge object-type-scalar"></span> GallonsPerMinute
---
# <span class="badge object-type-scalar"></span> GallonsPerMinute

Flow: Gallons/min (gpm)

## Definition

```python
# Flow: Gallons/min (gpm)
GallonsPerMinute: typing.Literal["flowgpm"] = "flowgpm"
```
